@@ -12,7 +12,14 @@ from ..utils import apply, derived_from
 from .core import Array, concatenate, dotmany, from_delayed
 from .creation import eye
 from .random import RandomState
-from .utils import meta_from_array, ones_like_safe, svd_flip
+from .utils import (
+    array_safe,
+    meta_from_array,
+    ones_like_safe,
+    solve_triangular_safe,
+    svd_flip,
+    zeros_like_safe,
+)
 
 
 def _cumsum_blocks(it):
@@ -964,9 +971,7 @@ def svd(a, coerce_signs=True):
 
 
 def _solve_triangular_lower(a, b):
-    import scipy.linalg
-
-    return scipy.linalg.solve_triangular(a, b, lower=True)
+    return solve_triangular_safe(a, b, lower=True)
 
 
 def lu(a):
@@ -985,7 +990,6 @@ def lu(a):
     l:  Array, lower triangular matrix with unit diagonal.
     u:  Array, upper triangular matrix
     """
-
     import scipy.linalg
 
     if a.ndim != 2:
@@ -1126,8 +1130,6 @@ def solve_triangular(a, b, lower=False):
         Solution to the system `a x = b`. Shape of return matches `b`.
     """
 
-    import scipy.linalg
-
     if a.ndim != 2:
         raise ValueError("a must be 2 dimensional")
     if b.ndim <= 2:
@@ -1188,14 +1190,18 @@ def solve_triangular(a, b, lower=False):
                         prevs.append(prev)
                     target = (operator.sub, target, (sum, prevs))
                 dsk[_key(i, j)] = (
-                    scipy.linalg.solve_triangular,
+                    solve_triangular_safe,
                     (a.name, i, i),
                     target,
                 )
 
     graph = HighLevelGraph.from_collections(name, dsk, dependencies=[a, b])
+
+    a_meta = meta_from_array(a)
+    b_meta = meta_from_array(b)
     res = _solve_triangular_lower(
-        np.array([[1, 0], [1, 2]], dtype=a.dtype), np.array([0, 1], dtype=b.dtype)
+        array_safe([[1, 0], [1, 2]], dtype=a.dtype, like=a_meta),
+        array_safe([0, 1], dtype=b.dtype, like=b_meta),
     )
     meta = meta_from_array(a, b.ndim, dtype=res.dtype)
     return Array(graph, name, shape=b.shape, chunks=b.chunks, meta=meta)
@@ -1251,9 +1257,7 @@ def inv(a):
 
 
 def _cholesky_lower(a):
-    import scipy.linalg
-
-    return scipy.linalg.cholesky(a, lower=True)
+    return np.linalg.cholesky(a)
 
 
 def cholesky(a, lower=False):
@@ -1287,7 +1291,6 @@ def _cholesky(a):
     Private function to perform Cholesky decomposition, which returns both
     lower and upper triangulars.
     """
-    import scipy.linalg
 
     if a.ndim != 2:
         raise ValueError("Dimension must be 2 to perform cholesky decomposition")
@@ -1321,7 +1324,11 @@ def _cholesky(a):
     for i in range(vdim):
         for j in range(hdim):
             if i < j:
-                dsk[name, i, j] = (np.zeros, (a.chunks[0][i], a.chunks[1][j]))
+                dsk[name, i, j] = (
+                    zeros_like_safe,
+                    meta_from_array(a),
+                    (a.chunks[0][i], a.chunks[1][j]),
+                )
                 dsk[name_upper, j, i] = (name, i, j)
             elif i == j:
                 target = (a.name, i, j)
@@ -1351,7 +1358,8 @@ def _cholesky(a):
 
     graph_upper = HighLevelGraph.from_collections(name_upper, dsk, dependencies=[a])
     graph_lower = HighLevelGraph.from_collections(name, dsk, dependencies=[a])
-    cho = scipy.linalg.cholesky(np.array([[1, 2], [2, 5]], dtype=a.dtype))
+    a_meta = meta_from_array(a)
+    cho = np.linalg.cholesky(array_safe([[1, 2], [2, 5]], dtype=a.dtype, like=a_meta))
     meta = meta_from_array(a, dtype=cho.dtype)
 
     lower = Array(graph_lower, name, shape=a.shape, chunks=a.chunks, meta=meta)
