@@ -9,8 +9,8 @@ from tlz import concat
 import dask
 import dask.array as da
 from dask.array.core import normalize_chunks
-from dask.array.utils import assert_eq, same_keys, AxisError
 from dask.array.numpy_compat import _numpy_117, _numpy_118
+from dask.array.utils import AxisError, assert_eq, same_keys
 
 
 @pytest.mark.parametrize(
@@ -73,6 +73,46 @@ def test_arr_like(funcname, shape, cast_shape, dtype, cast_chunks, chunks, name,
         assert not np.isfortran(da_r.compute())
 
 
+@pytest.mark.skipif(
+    not _numpy_117, reason="requires NumPy>=1.17 for shape argument support"
+)
+@pytest.mark.parametrize(
+    "funcname, kwargs",
+    [
+        ("empty_like", {}),
+        ("ones_like", {}),
+        ("zeros_like", {}),
+        ("full_like", {"fill_value": 5}),
+    ],
+)
+@pytest.mark.parametrize(
+    "shape, chunks, out_shape",
+    [
+        ((10, 10), (4, 4), None),
+        ((10, 10), (4, 4), (20, 3)),
+        ((10, 10), (4), (20)),
+        ((10, 10, 10), (4, 2), (5, 5)),
+        ((2, 3, 5, 7), None, (3, 5, 7)),
+        ((2, 3, 5, 7), (2, 5, 3), (3, 5, 7)),
+        ((2, 3, 5, 7), (2, 5, 3, "auto", 3), (11,) + (2, 3, 5, 7)),
+        ((2, 3, 5, 7), "auto", (3, 5, 7)),
+    ],
+)
+@pytest.mark.parametrize("dtype", ["i4"])
+def test_arr_like_shape(funcname, kwargs, shape, dtype, chunks, out_shape):
+    np_func = getattr(np, funcname)
+    da_func = getattr(da, funcname)
+    a = np.random.randint(0, 10, shape).astype(dtype)
+    np_r = np_func(a, shape=out_shape, **kwargs)
+    da_r = da_func(a, chunks=chunks, shape=out_shape, **kwargs)
+
+    assert np_r.shape == da_r.shape
+    assert np_r.dtype == da_r.dtype
+
+    if "empty" not in funcname:
+        assert_eq(np_r, da_r)
+
+
 @pytest.mark.parametrize("endpoint", [True, False])
 def test_linspace(endpoint):
     darr = da.linspace(6, 49, endpoint=endpoint, chunks=5)
@@ -325,53 +365,21 @@ def test_meshgrid_inputcoercion():
     assert_eq(z, z_d)
 
 
-def test_tril_triu():
-    A = np.random.randn(20, 20)
-    for chk in [5, 4]:
-        dA = da.from_array(A, (chk, chk))
-
-        assert np.allclose(da.triu(dA).compute(), np.triu(A))
-        assert np.allclose(da.tril(dA).compute(), np.tril(A))
-
-        for k in [
-            -25,
-            -20,
-            -19,
-            -15,
-            -14,
-            -9,
-            -8,
-            -6,
-            -5,
-            -1,
-            1,
-            4,
-            5,
-            6,
-            8,
-            10,
-            11,
-            15,
-            16,
-            19,
-            20,
-            21,
-        ]:
-            assert np.allclose(da.triu(dA, k).compute(), np.triu(A, k))
-            assert np.allclose(da.tril(dA, k).compute(), np.tril(A, k))
-
-
-def test_tril_triu_errors():
-    A = np.random.randint(0, 11, (10, 10, 10))
-    dA = da.from_array(A, chunks=(5, 5, 5))
-    pytest.raises(ValueError, lambda: da.triu(dA))
-
-
-def test_tril_triu_non_square_arrays():
-    A = np.random.randint(0, 11, (30, 35))
-    dA = da.from_array(A, chunks=(5, 5))
-    assert_eq(da.triu(dA), np.triu(A))
-    assert_eq(da.tril(dA), np.tril(A))
+@pytest.mark.parametrize(
+    "N, M, k, dtype, chunks",
+    [
+        (3, None, 0, float, "auto"),
+        (4, None, 0, float, "auto"),
+        (3, 4, 0, bool, "auto"),
+        (3, None, 1, int, "auto"),
+        (3, None, -1, int, "auto"),
+        (3, None, 2, int, 1),
+        (6, 8, -2, int, (3, 4)),
+        (6, 8, 0, int, (3, "auto")),
+    ],
+)
+def test_tri(N, M, k, dtype, chunks):
+    assert_eq(da.tri(N, M, k, dtype, chunks), np.tri(N, M, k, dtype))
 
 
 def test_eye():
@@ -454,7 +462,7 @@ def test_diagonal():
     assert_eq(da.diagonal(v, axis1=-1), np.diagonal(v, axis1=-1))
     assert_eq(da.diagonal(v, offset=1, axis1=-1), np.diagonal(v, offset=1, axis1=-1))
 
-    # Heterogenous chunks.
+    # Heterogeneous chunks.
     v = np.arange(2 * 3 * 4 * 5 * 6).reshape((2, 3, 4, 5, 6))
     v = da.from_array(v, chunks=(1, (1, 2), (1, 2, 1), (2, 1, 2), (5, 1)))
 
@@ -767,7 +775,10 @@ def test_pad(shape, chunks, pad_width, mode, kwargs):
                 reason="Bug when pad_width is larger than dimension: https://github.com/dask/dask/issues/5303"
             ),
         ),
-        pytest.param("median", marks=pytest.mark.skip(reason="Not implemented"),),
+        pytest.param(
+            "median",
+            marks=pytest.mark.skip(reason="Not implemented"),
+        ),
         pytest.param(
             "empty",
             marks=pytest.mark.skip(
