@@ -13,7 +13,7 @@ from dask.dataframe.utils import (
     assert_eq,
     clear_known_categories,
     is_categorical_dtype,
-    make_meta,
+    make_meta_util,
 )
 
 # Generate a list of categorical series and indices
@@ -120,8 +120,9 @@ def test_unknown_categoricals():
     ddf = dd.DataFrame(
         {("unknown", i): df for (i, df) in enumerate(frames)},
         "unknown",
-        make_meta(
-            {"v": "object", "w": "category", "x": "i8", "y": "category", "z": "f8"}
+        make_meta_util(
+            {"v": "object", "w": "category", "x": "i8", "y": "category", "z": "f8"},
+            parent_meta=frames[0],
         ),
         [None] * 4,
     )
