@@ -4,7 +4,7 @@ import pytest
 
 import dask.dataframe as dd
 from dask.dataframe._compat import tm
-from dask.dataframe.utils import assert_eq, make_meta
+from dask.dataframe.utils import assert_eq, make_meta_util
 
 
 @pytest.mark.parametrize(
@@ -149,7 +149,9 @@ def test_get_dummies_errors():
     # unknown categories
     df = pd.DataFrame({"x": list("abcbc"), "y": list("bcbcb")})
     ddf = dd.from_pandas(df, npartitions=2)
-    ddf._meta = make_meta({"x": "category", "y": "category"})
+    ddf._meta = make_meta_util(
+        {"x": "category", "y": "category"}, parent_meta=pd.DataFrame()
+    )
 
     with pytest.raises(NotImplementedError):
         dd.get_dummies(ddf)
@@ -257,7 +259,9 @@ def test_pivot_table_errors():
     assert msg in str(err.value)
 
     # unknown categories
-    ddf._meta = make_meta({"A": object, "B": float, "C": "category"})
+    ddf._meta = make_meta_util(
+        {"A": object, "B": float, "C": "category"}, parent_meta=pd.DataFrame()
+    )
     msg = "'columns' must have known categories"
     with pytest.raises(ValueError) as err:
         dd.pivot_table(ddf, index="A", columns="C", values=["B"])
